from enum import Enum

class RabbitMQRoutingKey(str, Enum):
    AUTH_OTP = 'AUTH_OTP'
    AUTH_LOGIN = 'AUTH_LOGIN'
    AUTH_DATA = 'AUTH_DATA'
    ACCOUNTS_ACTIVITY = 'ACCOUNTS_ACTIVITY'
    POSTS_CREATE = 'POSTS_CREATE'
    POSTS_LIST = 'POSTS_LIST'
    POSTS_GET = 'POSTS_GET'
    POSTS_DELETE = 'POSTS_DELETE'
    POSTS_UPDATE = 'POSTS_UPDATE'
    POSTS_COMPLETION = 'POSTS_COMPLETION'
    ORDERS_LIST = 'ORDERS_LIST'
    ORDERS_LABELS_GET = 'ORDERS_LABELS_GET'
    ORDERS_LABELS_CREATE = 'ORDERS_LABELS_CREATE'
    CONVERSATIONS_INBOX_GET = 'CONVERSATIONS_INBOX_GET'
    CONVERSATIONS_GET = 'CONVERSATIONS_GET'
    CONVERSATIONS_MESSAGES_CREATE = 'CONVERSATIONS_MESSAGES_CREATE'
    CONVERSATIONS_OFFERS_CREATE = 'CONVERSATIONS_OFFERS_CREATE'
    CONVERSATIONS_OFFERS_UPDATE = 'CONVERSATIONS_OFFERS_UPDATE'
